==> Scientific.0.8.9.tar.gz: SAFoundation.framework/Versions/A/Headers/SAFoundation.h <==
/* SAFoundation.h created by ahoesch on Thu 14-Jun-2001 */

#import <SAFoundation/Bibliography.h>
#import <SAFoundation/Body.h>
#import <SAFoundation/Document.h>
#import <SAFoundation/Bookmark.h>
#import <SAFoundation/Figure.h>
#import <SAFoundation/FigureCarrier.h>
#import <SAFoundation/Footnote.h>
#import <SAFoundation/Formula.h>
#import <SAFoundation/FormulaCarrier.h>
#import <SAFoundation/FormulaCell.h>
#import <SAFoundation/LicenseManager.h>
#import <SAFoundation/SAFoundationExtensions.h>
#import <SAFoundation/Property.h>
#import <SAFoundation/Section.h>
#import <SAFoundation/Category.h>
#import <SAFoundation/Chapter.h>
#import <SAFoundation/Book.h>
#import <SAFoundation/Link.h>
#import <SAFoundation/Reference.h>
#import <SAFoundation/Folder.h>
#import <SAFoundation/FolderFile.h>
#import <SAFoundation/Wrapper.h>
#import <SAFoundation/WrapperCarrier.h>
#import <SAFoundation/Theorem.h>
#import <SAFoundation/LinkTargetProtocol.h>
#import <SAFoundation/LaTeXGeneratorProtocol.h>
#import <SAFoundation/HTMLGeneratorProtocol.h>
#import <SAFoundation/PresentableRootObjectProtocol.h>
#import <SAFoundation/CreateLaTeXWorkerProtocol.h>
#import <SAFoundation/LaTeXPreferencesPageController.h>
#import <SAFoundation/FilterPreferencesPageController.h>
#import <SAFoundation/HTMLPreferencesPageController.h>
#import <SAFoundation/LicensePreferencesPageController.h>
#import <SAFoundation/DocumentClassPreferencesPageController.h>
#import <SAFoundation/InfoCenter.h>
#import <SAFoundation/Signature.h>
#import <SAFoundation/ObjectArchiving.h>
#import <SAFoundation/InspectorPageProtocols.h>
#import <SAFoundation/ImageConverter.h>
#import <SAFoundation/SAStroke.h>
#import <SAFoundation/SAStrokeManager.h>
#import <SAFoundation/Part.h>
#import <SAFoundation/TextPart.h>
#import <SAFoundation/SubPart.h>
#import <SAFoundation/StackPart.h>
#import <SAFoundation/VectorPart.h>
#import <SAFoundation/BlockPart.h>
#import <SAFoundation/MatrixPart.h>
#import <SAFoundation/ParentPart.h>
#import <SAFoundation/SchemePart.h>
#import <SAFoundation/IntegralPart.h>
#import <SAFoundation/RootPart.h>
#import <SAFoundation/ExpressionPart.h>
#import <SAFoundation/OperatorManager.h>
#import <SAFoundation/FunctionManager.h>
#import <SAFoundation/SelectFunctionController.h>
#import <SAFoundation/FBUserDefaults.h>
#import <SAFoundation/MathMLParser.h>
#import <SAFoundation/Definitions.h>
#import <SAFoundation/Fencer.h>
#import <SAFoundation/ScalingScrollView.h>
#import <SAFoundation/DocumentClassContainerView.h>
#import <SAFoundation/CountCenter.h>
#import <SAFoundation/PropertyCarrierProtocol.h>
#import <SAFoundation/EmphasisCarrier.h>
#import <SAFoundation/TheoremCarrier.h>
#import <SAFoundation/EnumerateCarrier.h>
#import <SAFoundation/Record.h>

enum {
   subscriptStroke		= 0xE000,
   superscriptStroke		= 0xE001,
   subsupStroke			= 0xE002,
   fractionStroke		= 0xE003,
   integralStroke		= 0xE004,
   upgradeStroke		= 0xE005,
   downgradeStroke		= 0xE006,
   rootStroke			= 0xE010,
   vectorAccentStroke		= 0xE013,
   vectorStroke			= 0xE00e,
   matrixStroke			= 0xE00f
};

==> Scientific.0.9.tar.gz: SAFoundation.framework/Versions/A/Headers/SAFoundation.h <==
/* SAFoundation.h created by ahoesch on Thu 14-Jun-2001 */

#import <SAFoundation/Bibliography.h>
#import <SAFoundation/Body.h>
#import <SAFoundation/Document.h>
#import <SAFoundation/Bookmark.h>
#import <SAFoundation/Figure.h>
#import <SAFoundation/FigureCarrier.h>
#import <SAFoundation/Footnote.h>
#import <SAFoundation/Formula.h>
#import <SAFoundation/FormulaCarrier.h>
#import <SAFoundation/FormulaCell.h>
#import <SAFoundation/LicenseManager.h>
#import <SAFoundation/SAFoundationExtensions.h>
#import <SAFoundation/Property.h>
#import <SAFoundation/Section.h>
#import <SAFoundation/Category.h>
#import <SAFoundation/Chapter.h>
#import <SAFoundation/Book.h>
#import <SAFoundation/Link.h>
#import <SAFoundation/Reference.h>
#import <SAFoundation/Folder.h>
#import <SAFoundation/FolderFile.h>
#import <SAFoundation/Wrapper.h>
#import <SAFoundation/WrapperCarrier.h>
#import <SAFoundation/Theorem.h>
#import <SAFoundation/LinkTargetProtocol.h>
#import <SAFoundation/LaTeXGeneratorProtocol.h>
#import <SAFoundation/HTMLGeneratorProtocol.h>
#import <SAFoundation/PresentableRootObjectProtocol.h>
#import <SAFoundation/CreateLaTeXWorkerProtocol.h>
#import <SAFoundation/LaTeXPreferencesPageController.h>
#import <SAFoundation/FilterPreferencesPageController.h>
#import <SAFoundation/HTMLPreferencesPageController.h>
#import <SAFoundation/LicensePreferencesPageController.h>
#import <SAFoundation/DocumentClassPreferencesPageController.h>
#import <SAFoundation/InfoCenter.h>
#import <SAFoundation/Signature.h>
#import <SAFoundation/ObjectArchiving.h>
#import <SAFoundation/InspectorPageProtocols.h>
#import <SAFoundation/ImageConverter.h>
#import <SAFoundation/SAStroke.h>
#import <SAFoundation/SAStrokeManager.h>
#import <SAFoundation/Part.h>
#import <SAFoundation/TextPart.h>
#import <SAFoundation/SubPart.h>
#import <SAFoundation/StackPart.h>
#import <SAFoundation/VectorPart.h>
#import <SAFoundation/BlockPart.h>
#import <SAFoundation/MatrixPart.h>
#import <SAFoundation/ParentPart.h>
#import <SAFoundation/SchemePart.h>
#import <SAFoundation/IntegralPart.h>
#import <SAFoundation/RootPart.h>
#import <SAFoundation/ExpressionPart.h>
#import <SAFoundation/OperatorManager.h>
#import <SAFoundation/FunctionManager.h>
#import <SAFoundation/SelectFunctionController.h>
#import <SAFoundation/FBUserDefaults.h>
#import <SAFoundation/MathMLParser.h>
#import <SAFoundation/PublicDefinitions.h>
#import <SAFoundation/Fencer.h>
#import <SAFoundation/ScalingScrollView.h>
#import <SAFoundation/DocumentClassContainerView.h>
#import <SAFoundation/CountCenter.h>
#import <SAFoundation/PropertyCarrierProtocol.h>
#import <SAFoundation/EmphasisCarrier.h>
#import <SAFoundation/TheoremCarrier.h>
#import <SAFoundation/EnumerateCarrier.h>
#import <SAFoundation/Record.h>
#import <SAFoundation/ProcessGateProtocol.h>

enum {
   subscriptStroke		= 0xE000,
   superscriptStroke		= 0xE001,
   subsupStroke			= 0xE002,
   fractionStroke		= 0xE003,
   integralStroke		= 0xE004,
   upgradeStroke		= 0xE005,
   downgradeStroke		= 0xE006,
   rootStroke			= 0xE010,
   vectorAccentStroke		= 0xE013,
   vectorStroke			= 0xE00e,
   matrixStroke			= 0xE00f
};

@interface SAFoundation : NSObject

+ (void)initialize_SAFoundation;

@end
